==> pipewire-docs-1:0.3.59-5-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/group__pw__core.js <==
var group__pw__core =
[
    [ "core.h", "core_8h.html", null ],
    [ "pw_core_info", "structpw__core__info.html", [
      [ "id", "structpw__core__info.html#ace1c72a0b6d18567a1156b2d961f63ca", null ],
      [ "cookie", "structpw__core__info.html#ab93eadf54d48e19762c4e6ebf5595083", null ],
      [ "user_name", "structpw__core__info.html#ad294c9fa79558c75141a731c4d812b42", null ],
      [ "host_name", "structpw__core__info.html#ade7cf9abf36e9cd82fe49ffa95159a2f", null ],
      [ "version", "structpw__core__info.html#a3e394e50023a597dafb391887249d4eb", null ],
      [ "change_mask", "structpw__core__info.html#a25d93390dbafcb433827ec29c195404f", null ]
    ] ],
    [ "pw_core_events", "structpw__core__events.html", [
      [ "version", "structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7", null ],
      [ "info", "structpw__core__events.html#a8433a5ea5115e8d914a70ba5dacd3b81", null ],
      [ "done", "structpw__core__events.html#acc0442d3b7d94005c8c63e5bd7b89473", null ],
      [ "ping", "structpw__core__events.html#a20931e5073a743e26c70957f85c10fd8", null ],
      [ "error", "structpw__core__events.html#a590bf80a38429eef4a94d2e8b7f82e56", null ],
      [ "remove_id", "structpw__core__events.html#a8a700a03453729d52d96112647125303", null ],
      [ "bound_id", "structpw__core__events.html#aab9b9d3a84837d892a4617c29f03e976", null ],
      [ "add_mem", "structpw__core__events.html#a7c1f8bd6078afab78aa943704efe7131", null ],
      [ "remove_mem", "structpw__core__events.html#a28cd6e2263efb69df702822028a45df2", null ]
    ] ],
    [ "pw_core_methods", "structpw__core__methods.html", [
      [ "version", "structpw__core__methods.html#af1831e5a0a805bf3ed47e48dbd09ee3a", null ],
      [ "add_listener", "structpw__core__methods.html#a05db653bcc20405f5b6ce5ccbe215703", null ],
      [ "hello", "structpw__core__methods.html#a47721985e4d0b24474f5598d0d94b6c5", null ],
      [ "sync", "structpw__core__methods.html#ab64487c2ddac4c7d315cc54a4d5b7176", null ],
      [ "pong", "structpw__core__methods.html#a23e319c72a886a40464d74e2e19f27f9", null ],
      [ "error", "structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa", null ],
      [ "get_registry", "structpw__core__methods.html#a570886edc43416b3dcd10b48016493af", null ],
      [ "create_object", "structpw__core__methods.html#a7e70c82277387a47a953d64b0ba82cce", null ],
      [ "destroy", "structpw__core__methods.html#a460ee1de46fe6e281c576cbe54841309", null ]
    ] ],
    [ "pw_core", "structpw__core.html", null ],
    [ "pw_registry", "structpw__registry.html", null ],
    [ "PW_TYPE_INTERFACE_Core", "group__pw__core.html#ga4828b5ffb309b2d8a985e0ee4fc80978", null ],
    [ "PW_TYPE_INTERFACE_Registry", "group__pw__core.html#gab77f9f893b6d0a0cc0827738479673e2", null ],
    [ "PW_VERSION_CORE", "group__pw__core.html#gaa1b9fbcde86380fd115be191535ccdf5", null ],
    [ "PW_VERSION_REGISTRY", "group__pw__core.html#gab44caf825808814cb78f9b6426457066", null ],
    [ "PW_DEFAULT_REMOTE", "group__pw__core.html#ga7a2591e137e97b0a693c0788031acab7", null ],
    [ "PW_ID_CORE", "group__pw__core.html#ga4083f3e9e51198a675c7fb0aa0f91769", null ],
    [ "PW_ID_ANY", "group__pw__core.html#ga5e904a63584ce9699c5c192bb4473cf9", null ],
    [ "PW_CORE_CHANGE_MASK_PROPS", "group__pw__core.html#ga787755cfb5d235fa3a961bcc7f65b3a8", null ],
    [ "PW_CORE_CHANGE_MASK_ALL", "group__pw__core.html#ga4c5b5cb41d6256b5262ca232f03ee6ef", null ],
    [ "PW_CORE_EVENT_INFO", "group__pw__core.html#ga20d8f8b7de5d61fd26279335081a650f", null ],
    [ "PW_CORE_EVENT_DONE", "group__pw__core.html#ga6320395eb7b0608d72876f528356d804", null ],
    [ "PW_CORE_EVENT_PING", "group__pw__core.html#gae5baf4bb04dc57c2f56c6ebe55495ee4", null ],
    [ "PW_CORE_EVENT_ERROR", "group__pw__core.html#ga26ec3a93936820d7766d161bd2061dde", null ],
    [ "PW_CORE_EVENT_REMOVE_ID", "group__pw__core.html#ga32442cfb83722413b8769555194f1837", null ],
    [ "PW_CORE_EVENT_BOUND_ID", "group__pw__core.html#ga7f5253f01173106d9f4204e6803f9eb7", null ],
    [ "PW_CORE_EVENT_ADD_MEM", "group__pw__core.html#gaa324107a2eb26e55ec2a6fab7c12cbc4", null ],
    [ "PW_CORE_EVENT_REMOVE_MEM", "group__pw__core.html#gaf42a0b2aece1dbb787791d92ccc9bf4c", null ],
    [ "PW_CORE_EVENT_NUM", "group__pw__core.html#gab5ff84f4e96706dcaf698a889d31ebb2", null ],
    [ "PW_VERSION_CORE_EVENTS", "group__pw__core.html#gaecb5def77dc04e427fda3af43fe56646", null ],
    [ "PW_CORE_METHOD_ADD_LISTENER", "group__pw__core.html#gab198dbd1143e47953104e4aa52106562", null ],
    [ "PW_CORE_METHOD_HELLO", "group__pw__core.html#ga91db1c249a8b6373869a6dc1461728b7", null ],
    [ "PW_CORE_METHOD_SYNC", "group__pw__core.html#ga7af83aeb249cf504499536e95793f650", null ],
    [ "PW_CORE_METHOD_PONG", "group__pw__core.html#ga4cf14818a2b4d7d2841e43d14706f24e", null ],
    [ "PW_CORE_METHOD_ERROR", "group__pw__core.html#gaad9f6725ef7bf5a40abc3993ee0eb661", null ],
    [ "PW_CORE_METHOD_GET_REGISTRY", "group__pw__core.html#ga61a14cc040ef8af2843ab3269292bee9", null ],
    [ "PW_CORE_METHOD_CREATE_OBJECT", "group__pw__core.html#ga3c4c5529b9bb6c9188053bdf1604c2e0", null ],
    [ "PW_CORE_METHOD_DESTROY", "group__pw__core.html#ga22add02684ab6cf7bcbb5971abf11b43", null ],
    [ "PW_CORE_METHOD_NUM", "group__pw__core.html#ga3377b3f78973fe86c320832c7c78ca11", null ],
    [ "PW_VERSION_CORE_METHODS", "group__pw__core.html#ga684305baa27764d91e1aef7faaf39afa", null ],
    [ "pw_core_method", "group__pw__core.html#gac59eea3db133de67f1b1c0ab4cab0047", null ],
    [ "pw_core_add_listener", "group__pw__core.html#gab938c1e0b4439c86f0c073d2359fefb0", null ],
    [ "pw_core_hello", "group__pw__core.html#gaeacb97f0a612cff9d5fdb16e2a205444", null ],
    [ "pw_core_sync", "group__pw__core.html#ga02b3e6ff573afd1efba25efc8bbb2538", null ],
    [ "pw_core_pong", "group__pw__core.html#ga50323f15b69d13b86fe1d59d6dd3bfba", null ],
    [ "pw_core_error", "group__pw__core.html#ga1c0700d8582be8c02db04c4f907b55c9", null ],
    [ "pw_core_destroy", "group__pw__core.html#ga747c2d5f60d3171f81ac5d58c34042a3", null ],
    [ "pw_core_info_update", "group__pw__core.html#gaf9ef57e634a1d3ba60e47a65608db03f", null ],
    [ "pw_core_info_merge", "group__pw__core.html#gae648ba2f9c03dabf37b4e1852a0c1924", null ],
    [ "pw_core_info_free", "group__pw__core.html#gacd6e564b199ca16be48656e77cb5003a", null ],
    [ "pw_core_errorv", "group__pw__core.html#ga06c0275ea988bc37118882895ec03433", null ],
    [ "pw_core_errorf", "group__pw__core.html#ga02ca8080671bb34a7f015eae9893bd9f", null ],
    [ "pw_core_get_registry", "group__pw__core.html#gac84664f761622bc7b98eabab717943af", null ],
    [ "pw_core_create_object", "group__pw__core.html#gaa0c5475dc6ef3a7d0c53383a5748ccc3", null ],
    [ "pw_context_connect", "group__pw__core.html#ga5994e3a54e4ec718094ca02a1234815b", null ],
    [ "pw_context_connect_fd", "group__pw__core.html#gae40b2a9bf4e42aac082bf90e37389c02", null ],
    [ "pw_context_connect_self", "group__pw__core.html#ga6c4082146d47a5da6db219fbd4d8ab1d", null ],
    [ "pw_core_steal_fd", "group__pw__core.html#gaab5fd68faa350ca3f2928032b0553a3f", null ],
    [ "pw_core_set_paused", "group__pw__core.html#gacd4995c9a07c46f925b28bf4c653f2df", null ],
    [ "pw_core_disconnect", "group__pw__core.html#gaa0ad30957ad355b5217f161cc7847c2f", null ],
    [ "pw_core_get_user_data", "group__pw__core.html#ga96e284c572b6ff30f66f796ccef6547b", null ],
    [ "pw_core_get_client", "group__pw__core.html#ga844067d3c4ee799eebb94db3d3c29e09", null ],
    [ "pw_core_get_context", "group__pw__core.html#ga00997c1dff9cc3e96934aea17ddcde94", null ],
    [ "pw_core_get_properties", "group__pw__core.html#ga6137f0b4ffe93b4051dc29baf262233d", null ],
    [ "pw_core_update_properties", "group__pw__core.html#ga9918e38cb727fa7b8d59cca7b318f3c7", null ],
    [ "pw_core_get_mempool", "group__pw__core.html#ga5b549ed4e92c3666c108591cb3ac3a55", null ],
    [ "pw_core_find_proxy", "group__pw__core.html#ga0f4adad3c19a2c184f6323f8d62443b1", null ],
    [ "pw_core_export", "group__pw__core.html#ga9f689fb870a35e081ceff7e689ad5e30", null ]
];

==> pipewire-docs-1:1.4.9-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/group__pw__core.js <==
var group__pw__core =
[
    [ "core.h", "core_8h.html", null ],
    [ "pw_core_info", "structpw__core__info.html", [
      [ "id", "structpw__core__info.html#ace1c72a0b6d18567a1156b2d961f63ca", null ],
      [ "cookie", "structpw__core__info.html#ab93eadf54d48e19762c4e6ebf5595083", null ],
      [ "user_name", "structpw__core__info.html#ad294c9fa79558c75141a731c4d812b42", null ],
      [ "host_name", "structpw__core__info.html#ade7cf9abf36e9cd82fe49ffa95159a2f", null ],
      [ "version", "structpw__core__info.html#a3e394e50023a597dafb391887249d4eb", null ],
      [ "change_mask", "structpw__core__info.html#a25d93390dbafcb433827ec29c195404f", null ]
    ] ],
    [ "pw_core_events", "structpw__core__events.html", [
      [ "version", "structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7", null ],
      [ "info", "structpw__core__events.html#a8433a5ea5115e8d914a70ba5dacd3b81", null ],
      [ "done", "structpw__core__events.html#acc0442d3b7d94005c8c63e5bd7b89473", null ],
      [ "ping", "structpw__core__events.html#a20931e5073a743e26c70957f85c10fd8", null ],
      [ "error", "structpw__core__events.html#a590bf80a38429eef4a94d2e8b7f82e56", null ],
      [ "remove_id", "structpw__core__events.html#a8a700a03453729d52d96112647125303", null ],
      [ "bound_id", "structpw__core__events.html#aab9b9d3a84837d892a4617c29f03e976", null ],
      [ "add_mem", "structpw__core__events.html#a7c1f8bd6078afab78aa943704efe7131", null ],
      [ "remove_mem", "structpw__core__events.html#a28cd6e2263efb69df702822028a45df2", null ],
      [ "bound_props", "structpw__core__events.html#a7e1a9d6c8598cee58b622cf61432769e", null ]
    ] ],
    [ "pw_core_methods", "structpw__core__methods.html", [
      [ "version", "structpw__core__methods.html#af1831e5a0a805bf3ed47e48dbd09ee3a", null ],
      [ "add_listener", "structpw__core__methods.html#a05db653bcc20405f5b6ce5ccbe215703", null ],
      [ "hello", "structpw__core__methods.html#a47721985e4d0b24474f5598d0d94b6c5", null ],
      [ "sync", "structpw__core__methods.html#ab64487c2ddac4c7d315cc54a4d5b7176", null ],
      [ "pong", "structpw__core__methods.html#a23e319c72a886a40464d74e2e19f27f9", null ],
      [ "error", "structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa", null ],
      [ "get_registry", "structpw__core__methods.html#a570886edc43416b3dcd10b48016493af", null ],
      [ "create_object", "structpw__core__methods.html#a7e70c82277387a47a953d64b0ba82cce", null ],
      [ "destroy", "structpw__core__methods.html#a460ee1de46fe6e281c576cbe54841309", null ]
    ] ],
    [ "pw_core", "structpw__core.html", null ],
    [ "pw_registry", "structpw__registry.html", null ],
    [ "PW_TYPE_INTERFACE_Core", "group__pw__core.html#ga4828b5ffb309b2d8a985e0ee4fc80978", null ],
    [ "PW_TYPE_INTERFACE_Registry", "group__pw__core.html#gab77f9f893b6d0a0cc0827738479673e2", null ],
    [ "PW_CORE_PERM_MASK", "group__pw__core.html#ga7e9ca43a0e33ab31c8f6073594f2352e", null ],
    [ "PW_VERSION_CORE", "group__pw__core.html#gaa1b9fbcde86380fd115be191535ccdf5", null ],
    [ "PW_VERSION_REGISTRY", "group__pw__core.html#gab44caf825808814cb78f9b6426457066", null ],
    [ "PW_API_CORE_IMPL", "group__pw__core.html#gab538b5fad93456d3317c17a88576d183", null ],
    [ "PW_API_REGISTRY_IMPL", "group__pw__core.html#ga904a943e3177e5feb2505e52b368a0e6", null ],
    [ "PW_DEFAULT_REMOTE", "group__pw__core.html#ga7a2591e137e97b0a693c0788031acab7", null ],
    [ "PW_ID_CORE", "group__pw__core.html#ga4083f3e9e51198a675c7fb0aa0f91769", null ],
    [ "PW_ID_ANY", "group__pw__core.html#ga5e904a63584ce9699c5c192bb4473cf9", null ],
    [ "PW_CORE_CHANGE_MASK_PROPS", "group__pw__core.html#ga787755cfb5d235fa3a961bcc7f65b3a8", null ],
    [ "PW_CORE_CHANGE_MASK_ALL", "group__pw__core.html#ga4c5b5cb41d6256b5262ca232f03ee6ef", null ],
    [ "PW_CORE_EVENT_INFO", "group__pw__core.html#ga20d8f8b7de5d61fd26279335081a650f", null ],
    [ "PW_CORE_EVENT_DONE", "group__pw__core.html#ga6320395eb7b0608d72876f528356d804", null ],
    [ "PW_CORE_EVENT_PING", "group__pw__core.html#gae5baf4bb04dc57c2f56c6ebe55495ee4", null ],
    [ "PW_CORE_EVENT_ERROR", "group__pw__core.html#ga26ec3a93936820d7766d161bd2061dde", null ],
    [ "PW_CORE_EVENT_REMOVE_ID", "group__pw__core.html#ga32442cfb83722413b8769555194f1837", null ],
    [ "PW_CORE_EVENT_BOUND_ID", "group__pw__core.html#ga7f5253f01173106d9f4204e6803f9eb7", null ],
    [ "PW_CORE_EVENT_ADD_MEM", "group__pw__core.html#gaa324107a2eb26e55ec2a6fab7c12cbc4", null ],
    [ "PW_CORE_EVENT_REMOVE_MEM", "group__pw__core.html#gaf42a0b2aece1dbb787791d92ccc9bf4c", null ],
    [ "PW_CORE_EVENT_BOUND_PROPS", "group__pw__core.html#gab1ff5ad63a43ec3138d88a6e1e118004", null ],
    [ "PW_CORE_EVENT_NUM", "group__pw__core.html#gab5ff84f4e96706dcaf698a889d31ebb2", null ],
    [ "PW_VERSION_CORE_EVENTS", "group__pw__core.html#gaecb5def77dc04e427fda3af43fe56646", null ],
    [ "PW_CORE_METHOD_ADD_LISTENER", "group__pw__core.html#gab198dbd1143e47953104e4aa52106562", null ],
    [ "PW_CORE_METHOD_HELLO", "group__pw__core.html#ga91db1c249a8b6373869a6dc1461728b7", null ],
    [ "PW_CORE_METHOD_SYNC", "group__pw__core.html#ga7af83aeb249cf504499536e95793f650", null ],
    [ "PW_CORE_METHOD_PONG", "group__pw__core.html#ga4cf14818a2b4d7d2841e43d14706f24e", null ],
    [ "PW_CORE_METHOD_ERROR", "group__pw__core.html#gaad9f6725ef7bf5a40abc3993ee0eb661", null ],
    [ "PW_CORE_METHOD_GET_REGISTRY", "group__pw__core.html#ga61a14cc040ef8af2843ab3269292bee9", null ],
    [ "PW_CORE_METHOD_CREATE_OBJECT", "group__pw__core.html#ga3c4c5529b9bb6c9188053bdf1604c2e0", null ],
    [ "PW_CORE_METHOD_DESTROY", "group__pw__core.html#ga22add02684ab6cf7bcbb5971abf11b43", null ],
    [ "PW_CORE_METHOD_NUM", "group__pw__core.html#ga3377b3f78973fe86c320832c7c78ca11", null ],
    [ "PW_VERSION_CORE_METHODS", "group__pw__core.html#ga684305baa27764d91e1aef7faaf39afa", null ],
    [ "pw_core_info_update", "group__pw__core.html#gaf9ef57e634a1d3ba60e47a65608db03f", null ],
    [ "pw_core_info_merge", "group__pw__core.html#gae648ba2f9c03dabf37b4e1852a0c1924", null ],
    [ "pw_core_info_free", "group__pw__core.html#gacd6e564b199ca16be48656e77cb5003a", null ],
    [ "pw_core_add_listener", "group__pw__core.html#ga6369c3a3b202f2581a1247d8e1dc4526", null ],
    [ "pw_core_hello", "group__pw__core.html#gafc0e9e04f87a833ce79c9d588a510a21", null ],
    [ "pw_core_sync", "group__pw__core.html#gace02dee4dcc159cf17e2b0e7826a9f9f", null ],
    [ "pw_core_pong", "group__pw__core.html#ga1b426b5fb218be6b56425bfd4828a6ab", null ],
    [ "pw_core_error", "group__pw__core.html#gafacdc4a43273b6c5c6d612bec3606df4", null ],
    [ "PW_API_CORE_IMPL", "group__pw__core.html#ga4780544d42d1bc68428b4b8806fefe4a", null ],
    [ "vsnprintf", "group__pw__core.html#ga85cb815b0408efda20fb583102424398", null ],
    [ "pw_core_error", "group__pw__core.html#ga2ee2b0be11f670fde6d095adbeb9b1f3", null ],
    [ "PW_API_CORE_IMPL", "group__pw__core.html#gaa13c4c5fdab043f3f32b89617ab74cb1", null ],
    [ "va_start", "group__pw__core.html#gad2d838c3c5fa3579c50656d4cc2fab4f", null ],
    [ "va_end", "group__pw__core.html#ga36af1f79dd6adf0809c21e76535034d5", null ],
    [ "pw_core_get_registry", "group__pw__core.html#ga94675f7e50b055abca0db031fda8ea2a", null ],
    [ "pw_core_create_object", "group__pw__core.html#ga90e274ffdd671cfa49cfcb5579f775c6", null ],
    [ "pw_core_destroy", "group__pw__core.html#ga6a6b955242fd9f4ed2e8acf375072897", null ],
    [ "pw_context_connect", "group__pw__core.html#ga5994e3a54e4ec718094ca02a1234815b", null ],
    [ "pw_context_connect_fd", "group__pw__core.html#gae40b2a9bf4e42aac082bf90e37389c02", null ],
    [ "pw_context_connect_self", "group__pw__core.html#ga6c4082146d47a5da6db219fbd4d8ab1d", null ],
    [ "pw_core_steal_fd", "group__pw__core.html#gaab5fd68faa350ca3f2928032b0553a3f", null ],
    [ "pw_core_set_paused", "group__pw__core.html#gacd4995c9a07c46f925b28bf4c653f2df", null ],
    [ "pw_core_disconnect", "group__pw__core.html#gaa0ad30957ad355b5217f161cc7847c2f", null ],
    [ "pw_core_get_user_data", "group__pw__core.html#ga96e284c572b6ff30f66f796ccef6547b", null ],
    [ "pw_core_get_client", "group__pw__core.html#ga844067d3c4ee799eebb94db3d3c29e09", null ],
    [ "pw_core_get_context", "group__pw__core.html#ga00997c1dff9cc3e96934aea17ddcde94", null ],
    [ "pw_core_get_properties", "group__pw__core.html#ga6137f0b4ffe93b4051dc29baf262233d", null ],
    [ "pw_core_update_properties", "group__pw__core.html#ga9918e38cb727fa7b8d59cca7b318f3c7", null ],
    [ "pw_core_get_mempool", "group__pw__core.html#ga5b549ed4e92c3666c108591cb3ac3a55", null ],
    [ "pw_core_find_proxy", "group__pw__core.html#ga0f4adad3c19a2c184f6323f8d62443b1", null ],
    [ "pw_core_export", "group__pw__core.html#ga9f689fb870a35e081ceff7e689ad5e30", null ],
    [ "id", "group__pw__core.html#gabaabdc509cdaba7df9f56c6c76f3ae19", null ],
    [ "seq", "group__pw__core.html#ga68b9392368595b9d2e01ca7b07c820e4", null ],
    [ "res", "group__pw__core.html#gac47bc0c8feb8377c35d99b9bd66b9137", null ],
    [ "message", "group__pw__core.html#gabdc784a574a73c467696f4032d108429", null ],
    [ "args", "group__pw__core.html#ga09e1b622f95566546aa5988cd51309c6", null ],
    [ "buffer", "group__pw__core.html#ga0ed1316569a083925a39be8454e714bb", null ],
    [ "r", "group__pw__core.html#gabebbd563889e01487720e640c3568788", null ]
];
